Data documentation compiled by Great Expectations

### titanic

### default

> > Titanic

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-08-02T175019.495089Z-BasicDatasetProfiler

### random

### default

> > f1

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-08-02T175019.659420Z-BasicDatasetProfiler

> > f2

####

##### Expectation Suites

BasicDatasetProfiler

####

##### Batch Validations

2019-08-02T175019.659420Z-BasicDatasetProfiler

Documentation autogenerated using Great Expectations.

This is a beta feature! Expect changes in API, behavior, and design.